@@ -28,7 +28,7 @@ class WizardAgent : public BluezQt::Agent
     Q_OBJECT
 
 public:
-    explicit WizardAgent(QObject *parent = 0);
+    explicit WizardAgent(QObject *parent = nullptr);
 
     QString pin();
     void setPin(const QString &pin);
@@ -36,13 +36,13 @@ public:
     bool isFromDatabase();
     QString getPin(BluezQt::DevicePtr device);
 
-    QDBusObjectPath objectPath() const Q_DECL_OVERRIDE;
+    QDBusObjectPath objectPath() const override;
 
-    void requestPinCode(BluezQt::DevicePtr device, const BluezQt::Request<QString> &req) Q_DECL_OVERRIDE;
-    void displayPinCode(BluezQt::DevicePtr device, const QString &pinCode) Q_DECL_OVERRIDE;
-    void requestPasskey(BluezQt::DevicePtr device, const BluezQt::Request<quint32> &req) Q_DECL_OVERRIDE;
-    void displayPasskey(BluezQt::DevicePtr device, const QString &passkey, const QString &entered) Q_DECL_OVERRIDE;
-    void requestConfirmation(BluezQt::DevicePtr device, const QString &passkey, const BluezQt::Request<> &req) Q_DECL_OVERRIDE;
+    void requestPinCode(BluezQt::DevicePtr device, const BluezQt::Request<QString> &req) override;
+    void displayPinCode(BluezQt::DevicePtr device, const QString &pinCode) override;
+    void requestPasskey(BluezQt::DevicePtr device, const BluezQt::Request<quint32> &req) override;
+    void displayPasskey(BluezQt::DevicePtr device, const QString &passkey, const QString &entered) override;
+    void requestConfirmation(BluezQt::DevicePtr device, const QString &passkey, const BluezQt::Request<> &req) override;
 
 Q_SIGNALS:
     void pinRequested(const QString &pin);
